@@ -117,7 +117,7 @@ class RDSClient():
                                       version_id: int) -> list:
         """
         """
-        query = f"SELECT d.id, d.uri FROM neuralplatform_document d, neuralplatform_dataset dat, neuralplatform_version v WHERE (d.tagged = 1 AND d.dataset_id = dat.id AND dat.project_id = {project_id} AND v.id = {version_id} AND (d.uploadDate BETWEEN v.startDate AND v.endDate));"
+        query = f"SELECT d.id, d.uri FROM neuralplatform_document d, neuralplatform_version v WHERE (d.project_id = {project_id} AND v.id = {version_id} AND (d.uploadDate BETWEEN v.startDate AND v.endDate));"
         return self.select_query(query, fetchone=False)
 
     def get_project(self,
@@ -161,7 +161,7 @@ class RDSClient():
     
     def update_page_img(self,
                         page_id: int,
-                        img_uri: str) -> int:
+                        img_uri: str) -> bool:
         """
         """
         query = f'UPDATE neuralplatform_page SET imgUri = "{img_uri}" WHERE id = {page_id};'
@@ -169,11 +169,27 @@ class RDSClient():
     
     def update_page_ocr(self,
                         page_id: int,
-                        ocr_uri: str) -> int:
+                        ocr_uri: str) -> bool:
         """
         """
         query = f'UPDATE neuralplatform_page SET ocrUri = "{ocr_uri}" WHERE id = {page_id};'
         return self.insert_query(query)
+    
+    def update_page_img_status(self,
+                               page_id: int,
+                               status: str) -> bool:
+        """
+        """
+        query = f'UPDATEneuralplatform_page SET imgStatus = "{status}" WHERE id = {page_id};'
+        return self.insert_query(query)
+    
+    def update_page_ocr_status(self,
+                               page_id: int,
+                               status: str) -> bool:
+        """
+        """
+        query = f'UPDATEneuralplatform_page SET ocrStatus = "{status}" WHERE id = {page_id};'
+        return self.insert_query(query)
 
     def get_page(self,
                  page_id: int):
@@ -182,25 +198,44 @@ class RDSClient():
         query = f"SELECT * FROM neuralplatform_page WHERE id = {page_id};"
         return self.select_query(query, fetchone=True)
     
+    def get_document_pages(self,
+                           document_id: int) -> list:
+        """
+        """
+        query = f"SELECT * FROM neuralplatform_page WHERE document_id = {document_id};"
+        return self.select_query(query)
+    
+    def check_preprocessed_pages(self,
+                                 page_ids: list) -> tuple:
+        """
+        """
+        img_status = list()
+        ocr_status = list()
+        for page_id in page_ids:
+            page = self.get_page(page_id)
+            img_status.append(page['imgStatus'])
+            ocr_status.append(page['ocrStatus'])
+        all_preprocessed = ( all([s in ("COMPLETED", "FAILED") for s in img_status]) and
+                             all([s in ("COMPLETED", "FAILED") for s in ocr_status]) )
+        return all_preprocessed, img_status, ocr_status
+    
     def get_preprocessed_pages(self,
-                               document_ids: list):
+                               page_ids: list):
         """
         """
         classes = []
         img_uris = []
         ocr_uris = []
-        for document_id in document_ids:
-            query = f"SELECT tagged FROM neuralplatform_document WHERE id = {document_id};"
-            if self.select_query(query, fetchone=True)['tagged']:
-                query = f"SELECT classDefinition_id FROM neuralplatform_classification WHERE document_id = {document_id};"
+        
+        for page_id in page_ids:
+            page = self.get_page(page_id)
+            if page['tagged'] and page['imgStatus'] == "COMPLETED" and page['ocrStatus'] == "COMPLETED":
+                query = f"SELECT classDefinition_id FROM neuralplatform_classification WHERE page_id = {page_id};"
                 class_id = self.select_query(query, fetchone=True)['classDefinition_id']
-                query = f"SELECT * FROM neuralplatform_page WHERE document_id = {document_id};"
-                pages = self.select_query(query)
-                for page in pages:
-                    if page['ocrUri'] and page['imgUri']:
-                        classes.append(class_id)
-                        img_uris.append(page['imgUri'])
-                        ocr_uris.append(page['ocrUri'])
+                classes.append(class_id)
+                img_uris.append(page['imgUri'])
+                ocr_uris.append(page['ocrUri'])
+
         return classes, img_uris, ocr_uris
 
     def get_project_num_classes(self,
@@ -209,6 +244,13 @@ class RDSClient():
         """
         query = f"SELECT COUNT(*) AS count FROM neuralplatform_classdefinition WHERE project_id = {project_id};"
         return self.select_query(query, fetchone=True)['count']
+    
+    def get_project_classes(self,
+                            project_id: int) -> list:
+        """
+        """
+        query = f"SELECT * FROM neuralplatform_classdefinition WHERE project_id = {project_id};"
+        return self.select_query(query)
 
     def insert_model(self,
                      version_id: int,
