@@ -116,13 +116,23 @@ class S3Client(Boto3Client):
         """
         self.put_object(Body=json.dumps(word2idx).encode(), Bucket=bucket, Key=f"{project_name}/config/word2idx.json")
 
-    def get_project_classes(self,
+    def get_version_classes(self,
                             bucket: str,
-                            project_name: str) -> dict:
+                            project_name: str,
+                            version_id: int) -> dict:
         """
         """
-        classes = self.get_object(Bucket=bucket, Key=f"{project_name}/config/classes.json")
+        classes = self.get_object(Bucket=bucket, Key=f"{project_name}/versions/{version_id}/datasets/classes.json")
         return json.loads(classes['Body'].read())
+    
+    def upload_version_classes(self,
+                               bucket: str,
+                               project_name: str,
+                               version_id: int,
+                               classes: list):
+        """
+        """
+        self.put_object(Body=json.dumps(classes).encode(), Bucket=bucket, Key=f"{project_name}/versions/{version_id}/datasets/classes.json")
 
     def create_account_bucket(self,
                               name: str,
